@@ -1,6 +1,8 @@
 """
 Usage:
   python3 -m cognifly controller
+  or
+  python3 -m cognifly controller-headless
 """
 
 import sys
@@ -10,5 +12,7 @@ _, cmd, *args = sys.argv
 
 if cmd == "controller":
     run_controller()
+elif cmd == "controller-headless":
+    run_controller(print_screen=False)
 else:
     raise AttributeError("Undefined command: " + cmd)
